==> syncope-2.0.14-source-release.zip: syncope-2.0.14/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/dao/Reportlet.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.dao;

import java.util.concurrent.atomic.AtomicReference;
import org.apache.syncope.common.lib.report.ReportletConf;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

/**
 * Interface for all elements that can be embedded in a report.
 *
 * @see org.apache.syncope.core.persistence.api.entity.Report
 */
public interface Reportlet {

    /**
     * Actual data extraction for reporting.
     *
     * @param conf configuration
     * @param handler SAX content handler for streaming result
     * @param status current report status (for job reporting)
     * @throws SAXException if there is any problem in SAX handling
     */
    void extract(ReportletConf conf, ContentHandler handler, AtomicReference<String> status) throws SAXException;
}

==> syncope-2.1.0-source-release.zip: syncope-2.1.0/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/dao/Reportlet.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.dao;

import java.util.concurrent.atomic.AtomicReference;
import org.apache.syncope.common.lib.report.ReportletConf;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

/**
 * Interface for all elements that can be embedded in a report.
 *
 * @see org.apache.syncope.core.persistence.api.entity.Report
 */
public interface Reportlet {

    /**
     * Optional configuration.
     *
     * @param conf configuration
     */
    default void setConf(ReportletConf conf) {
    }

    /**
     * Actual data extraction for reporting.
     *
     * @param handler SAX content handler for streaming result
     * @param status current report status (for job reporting)
     * @throws SAXException if there is any problem in SAX handling
     */
    void extract(ContentHandler handler, AtomicReference<String> status) throws SAXException;
}
